ElfLibrary

Struct ElfLibrary 

pub struct ElfLibrary { /* private fields */ }
Represents a successfully loaded and relocated dynamic library.

This is the primary interface for interacting with a loaded library, providing methods to look up symbols and inspect metadata.

Implementations

Source

impl ElfLibrary

pub fn dl_iterate_phdr<F>(callback: F) -> Result<()>
where F: FnMut(&DlPhdrInfo<'_>) -> Result<()>,

Iterate over the program headers of all dynamic libraries.

Source

impl ElfLibrary

pub fn dladdr(addr: usize) -> Option<DlInfo>

determines whether the address specified in addr is located in one of the shared objects loaded by the calling application. If it is, then dladdr returns information about the shared object and symbol that overlaps addr.

Source

impl ElfLibrary

pub fn this() -> ElfLibrary

Get the main executable as an ElfLibrary. It is the same as dlopen(NULL, RTLD_NOW).

pub fn dlopen(path: impl AsFilename, flags: OpenFlags) -> Result<ElfLibrary>

Load a shared library from a specified path. It is the same as dlopen.

Example

let path = "/path/to/library.so";
let lib = ElfLibrary::dlopen(path, OpenFlags::RTLD_LOCAL).expect("Failed to load library");
pub fn dlopen_from_binary( bytes: &[u8], path: impl AsFilename, flags: OpenFlags, ) -> Result<ElfLibrary>

Load a shared library from bytes. It is the same as dlopen. However, it can also be used in the no_std environment, and it will look for dependent libraries in those manually opened dynamic libraries.

Source

impl ElfLibrary

pub fn name(&self) -> &str

Get the name of the dynamic library.

pub fn cname(&self) -> *const c_char

Get the C-style name of the dynamic library.

pub fn shortname(&self) -> &str

Get the short name of the dynamic library.

pub fn flags(&self) -> OpenFlags

Get the current flags of the dynamic library from the global registry.

pub fn base(&self) -> usize

Get the base address of the dynamic library.

pub fn mapped_len(&self) -> usize

Gets the memory length of the elf object map.

pub fn phdrs(&self) -> Option<&[ElfPhdr]>

Get the program headers of the dynamic library.

pub fn needed_libs(&self) -> &[String]

Get the needed libs’ name of the elf object.

pub unsafe fn get<'lib, T>(&'lib self, name: &str) -> Result<Symbol<'lib, T>>

Get a pointer to a function or static variable by symbol name.

The symbol is interpreted as-is; no mangling is done. This means that symbols like x::y are most likely invalid.

Safety

Users of this API must specify the correct type of the function or variable loaded.

Examples
unsafe {
    let awesome_function: Symbol<unsafe extern fn(f64) -> f64> =
        lib.get("awesome_function").unwrap();
    awesome_function(0.42);
}

A static variable may also be loaded and inspected:

unsafe {
    let awesome_variable: Symbol<*mut f64> = lib.get("awesome_variable").unwrap();
    **awesome_variable = 42.0;
};